@@ -9,6 +9,11 @@ formula_1 <- formulaic::reduce.existing.formula(
   max.input.categories = 30
 )
 
-test_that('Reduce formula',
-          expect_equal(formula_1$formula,Awareness ~ Age + Gender + Income + Region + Persona + Product +
-                         `Age Group` + `Income Group`))
+test_that(
+  'Reduce formula',
+  expect_equal(
+    formula_1$formula,
+    Awareness ~ Age + Gender + Income + Region + Persona + Product +
+      `Age Group` + `Income Group`
+  )
+)
